% Cascade of neural processing orchestrates cognitive control in human frontal cortex
% Hanlin Tang, Hsiang-Yu Yu, Chien-Chen Chou, Nathan E. Crone, Joseph R. Madsen, William S. Anderson, Gabriel Kreiman
%
% This script plots Figure 4, panels A, B, D, and E.
% Tested with MATLAB 7.14 (R2012a)

load figure3+4_sourceData

%% PLOT Incongruent/Congruent log ratio
green = [0 0.5 0];
blue = [0 0 0.5];

figure(4); clf; set(gcf,'Color','w');
set(gcf,'Position',[0 703 670 175]);

subplot(1,3,1); 

% truncate ratios to [XMIN XMAX] for display. Truncated values appear in
% the last bin. 
XMIN = -0.35;
XMAX = 0.5;
ratio_reading = max(data.reading_logratio_Inc_con,XMIN); 
ratio_stroop = max(data.stroop_logratio_Inc_con,XMIN);


% histogram the log-ratios
X = [-Inf XMIN:0.05:0.5 Inf];
Nreading = histc(ratio_reading,X);
Nstroop = histc(ratio_stroop,X);

% define the last and first bins
X(end) = X(end-1)+0.05;
X(1) = X(2)-0.05;

% plot histograms
[xx,yy] = stairs(X,Nreading); hold on;
h = patch(xx,yy,green); set(h,'FaceAlpha',0.6,'EdgeColor','none');
[xx,yy] = stairs(X,Nstroop); hold on;
h = patch(xx,yy,blue); set(h,'FaceAlpha',0.6,'EdgeColor','none'); hold on;

% plot zero line. A log-ratio of 0 means the ratio is equal to 1.
plot([0 0],[0 22],'k-');

% figure settings
xlim([XMIN-0.05 XMAX+0.05]);
ylim([0 22]);
box off;
xlabel('\gamma-power ratio (Inc/Con)');
set(gca,'TickDir','out');
set(gca,'TickLength',[0.03 0.03]);
set(gca,'XTick',[-0.6:0.2:0.6]); set(gca,'YTick',5:5:20);
ylabel('Number of Electrodes');

%% PLOT cI/iI log ratio
subplot(1,3,2);
XMIN = -0.35;
XMAX = 0.5;
ratio_reading = max(data.reading_logratio_cI_iI,XMIN); 
ratio_stroop = max(data.stroop_logratio_cI_iI,XMIN);

% histogram the log-ratios
X = [-Inf XMIN:0.05:0.5 Inf];
Nreading = histc(ratio_reading,X);
Nstroop = histc(ratio_stroop,X);

% define the last and first bins
X(end) = X(end-1)+0.05;
X(1) = X(2)-0.05;

% plot histograms
[xx,yy] = stairs(X,Nreading); hold on;
h = patch(xx,yy,green); set(h,'FaceAlpha',0.6,'EdgeColor','none');
[xx,yy] = stairs(X,Nstroop); hold on;
h = patch(xx,yy,blue); set(h,'FaceAlpha',0.6,'EdgeColor','none'); hold on;

% plot zero line. A log-ratio of 0 means the ratio is equal to 1.
plot([0 0],[0 22],'k-');

% figure settings
xlim([XMIN-0.05 XMAX+0.05]);
ylim([0 22]);
box off;
xlabel('\gamma-power ratio (cI/iI)');
set(gca,'TickDir','out');
set(gca,'TickLength',[0.03 0.03]);
set(gca,'XTick',[-0.6:0.2:0.6]); set(gca,'YTick',5:5:20);
ylabel('Number of Electrodes');

%% PLOT iC/CC log ratio

subplot(1,3,3);
XMIN = -0.35;
XMAX = 0.5;
ratio_reading = max(data.reading_logratio_iC_cC,XMIN); 
ratio_stroop = max(data.stroop_logratio_iC_cC,XMIN);

% histogram the log-ratios
X = [-Inf XMIN:0.05:0.5 Inf];
Nreading = histc(ratio_reading,X);
Nstroop = histc(ratio_stroop,X);

% define the last and first bins
X(end) = X(end-1)+0.05;
X(1) = X(2)-0.05;

% plot histograms
[xx,yy] = stairs(X,Nreading); hold on;
h = patch(xx,yy,green); set(h,'FaceAlpha',0.6,'EdgeColor','none');
[xx,yy] = stairs(X,Nstroop); hold on;
h = patch(xx,yy,blue); set(h,'FaceAlpha',0.6,'EdgeColor','none'); hold on;

% plot zero line. A log-ratio of 0 means the ratio is equal to 1.
plot([0 0],[0 22],'k-');

% figure settings
xlim([XMIN-0.05 XMAX+0.05]);
ylim([0 22]);
box off;
xlabel('\gamma-power ratio (iC/cC)');
set(gca,'TickDir','out');
set(gca,'TickLength',[0.03 0.03]);
set(gca,'XTick',[-0.6:0.2:0.6]); set(gca,'YTick',5:5:20);
ylabel('Number of Electrodes');

%% PLOT region average low-power ratios

% define the regions
region_group = NaN(length(data.region_code),1);
region_group(ismember(data.region_code,[6 7])) = 1; % ACC
region_group(ismember(data.region_code,16)) = 2; % mFC
region_group(ismember(data.region_code,15)) = 3; % dlPFC
region_group(ismember(data.region_code,[5 1 24 13])) = 4; % OFC

power_congruent = NaN(543,length(data)); % [NSAMPLES x NELECTRODES]
power_incongruent = NaN(543,length(data)); % [NSAMPLES x NELECTRODES]

% loop through all the data, and resample the waveforms
% if neccessary. Each patient has a different sampling rate, requiring this
% step.
for k = 1:length(data)
    congruent = data.average_power{k}(:,1);
    incongruent = data.average_power{k}(:,2);
    
    power_congruent(:,k) = resample(congruent,543,length(congruent));
    power_incongruent(:,k) = resample(incongruent,543,length(incongruent));
end

% compute the log ratio
logratio = log(power_incongruent./power_congruent);

%%

figure(5); clf; set(gcf,'Color','w');
set(gcf,'Position',[800 900 226 214]);
region_names = {'ACC','mFC','dlPFC','OFC'};
times2plot = time > -2.5 & time < 1.5; % plot times from -2.5 to 1.5seconds relative to response onset.

% graphics
region_colors = [59 137 175; 70 107 50; 144 104 172; 201 164 128]/255;


for k = 1:4
    subplot(2,2,k);
    
    idx = region_group == k;
    
    % compute average and sem
    mu = mean(logratio(:,idx),2);
    sem = std(logratio(:,idx),[],2)/sqrt(sum(idx));
    
    % plot curve
    shadedErrorBar(time(times2plot), mu(times2plot), sem(times2plot),{'Color',region_colors(k,:)}); hold on;

    % plot t=0 (response onset) line
    plot([0 0],[-0.2 0.3],'-','Color',[0 0 0]);
    
    % write region label
    title(region_names{k},'Color',region_colors(k,:));
    
    
    % figure settings
    box off;
    xlim([-2.5 1.5]);
    ylim([-0.15 0.3]);
    
    if(ismember(k,[3 4]))
        xlabel('Time (s)');
        set(gca,'XTick',[-2:1:2]);  
    else
        set(gca,'XTick',[]);     
    end
    if(ismember(k,[1 3]))
        ylabel('Log-ratio of Inc/Con');
    end

    set(gca,'TickDir','out');
    set(gca,'TickLength',[0.025 0.025]);
    set(gca,'YTick',[-0.2:0.1:0.2]); 
    

end

 














